==> kom%2B%2B-0.2.tar.gz: kom++-0.2/other-clients/garb.cc <==
// Demoprogram till GARB, augusti 1993.
//
// Programmet kopplar upp sig mot kom.lysator.liu.se och ser efter vad
// mte nummer 5 har fr namn. Det anvnder sig av ett antal olika
// metoder fr att demonstrera dem.
//
// Det r troligt att vissa saker kommer att ndra sig ganska snart
// (kanske redan innan du lser denna GARB). De saker vi rknar med
// att ndra har vi markerat med "Not 1". Det gller hur man hanterar
// fel som uppstr nr man frsker hmta ngot ur cachen. Just nu ska
// man kontrollera att foo.errno() == 0. Vi infr kanske ngon annan
// metod snart.
//
// Detta program r skrivet av Per Cederqvist. Inge Wallin var med och
// bestmde vad det skulle gra.
//
// Detta program r, till skillnad mot resten av kom++, Public Domain.
//
#include <stdlib.h>
#include <iostream.h>
#include "connection.h"
#include "conference.h"
#include "conf-stat.h"
#include "conf-cache.h"
#include "get_conf_stat_q.h"

int main()
{
  // Denna variabel anvnds i alla exempel fr att mellanlagra aktuell
  // mtesstatus.
  Conf_stat   conf_stat;
  
  // Koppla upp mot servern. Objektet ``conn'' str fr frbindelsen.
  Connection conn("kom.lysator.liu.se", "4894");

  // Hmta namn med hjlp av question.
  get_conf_stat_question c(&conn, 5);
  if (c.receive() == st_error)
    abort();
  conf_stat = c.result();
  cout << "Resultat med question: " << conf_stat.name() << endl;

  // Gr samma sak med hjlp av cachen. Frst mste vi skapa en cache.
  // I det hr fallet skapar vi bara en cache fr Conf_stat:tar. Vi
  // kallar den f|r CC och hoppas att Pripps ska se detta och sponsra
  // oss. Det har gtt t mnga liter Coca Cola medan vi skrev
  // LysKOM...
  Conf_cache   CC(&conn);

  conf_stat = CC.get(5);
  if (conf_stat.errno() != 0)	// Not 1.
    abort();
  cout << "Resultat med cachen: " << conf_stat.name() << endl;

  // n en gng gr vi samma sak (det brjar nstan bli tjatigt nu),
  // men denna gng anvnder vi oss av en nnu hgre abstraktionsniv.
  // Vi brjar med att skapa ett objekt som str fr mngden av alla
  // Conf_stat:tar.
  Conferences   all_confs(&conn);

  if (all_confs[5].errno() != 0) // Not 1.
    abort();

  cout << "Resultat med Conferences: " << all_confs[5].name() << endl;

  return 0;
}

==> kom%2B%2B-0.7.post.6.tar.gz: kom++-0.7.post.6/other-clients/garb.cc <==
// Demoprogram till GARB, augusti 1993.
//
// Programmet kopplar upp sig mot kom.lysator.liu.se och ser efter vad
// mte nummer 5 har fr namn. Det anvnder sig av ett antal olika
// metoder fr att demonstrera dem.
//
// Det r troligt att vissa saker kommer att ndra sig ganska snart
// (kanske redan innan du lser denna GARB). De saker vi rknar med
// att ndra har vi markerat med "Not 1". Det gller hur man hanterar
// fel som uppstr nr man frsker hmta ngot ur cachen. Just nu ska
// man kontrollera att foo.errno() == 0. Vi infr kanske ngon annan
// metod snart.
//
// Detta program r skrivet av Per Cederqvist. Inge Wallin var med och
// bestmde vad det skulle gra.
//
// Detta program r, till skillnad mot resten av kom++, Public Domain.
//

#include <config.h>

#include <cstdlib>
#include <iostream>

#include "connection.h"
#include "conference.h"
#include "conf-stat.h"
#include "conf-cache.h"
#include "get_conf_stat_q.h"
#include "conn_io_isc.h"

int main()
{
  // Denna variabel anvnds i alla exempel fr att mellanlagra aktuell
  // mtesstatus.
  Conf_stat   conf_stat;
  
  // Koppla upp mot servern. Objektet ``conn'' str fr frbindelsen.
  Conn_io_ISC isc("kom.lysator.liu.se", "4894");
  Connection conn(&isc);
  Async_dispatcher disp(&conn);

  // Hmta namn med hjlp av question.
  get_conf_stat_question c(&conn, 5);
  if (c.receive() == st_error)
    abort();
  conf_stat = c.result();
  std::cout << "Resultat med question: " << conf_stat.name() << std::endl;

  // Gr samma sak med hjlp av cachen. Frst mste vi skapa en cache.
  // I det hr fallet skapar vi bara en cache fr Conf_stat:tar. Vi
  // kallar den f|r CC och hoppas att Pripps ska se detta och sponsra
  // oss. Det har gtt t mnga liter Coca Cola medan vi skrev
  // LysKOM...
  Conf_cache   CC(&conn, &disp);

  conf_stat = CC.get(5);
  if (conf_stat.kom_errno() != 0)	// Not 1.
    abort();
  std::cout << "Resultat med cachen: " << conf_stat.name() << std::endl;

  // n en gng gr vi samma sak (det brjar nstan bli tjatigt nu),
  // men denna gng anvnder vi oss av en nnu hgre abstraktionsniv.
  // Vi brjar med att skapa ett objekt som str fr mngden av alla
  // Conf_stat:tar.
  Conferences   all_confs(&conn, &disp);

  if (all_confs[5].kom_errno() != 0) // Not 1.
    std::abort();

  std::cout << "Resultat med Conferences: " << all_confs[5].name() 
	    << std::endl;

  return 0;
}
